using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;

using Syncfusion.Windows.Forms.Diagram;

namespace ZoomRichText
{
	/// <summary>
	/// Summary description for ZoomRichTextNode.
	/// </summary>
	public class ZoomRichTextNode : RichTextNode
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		public ZoomRichTextNode() : base()
		{
		}

		/// <summary>
		/// Construct a RichTextNode given a string of rich text.
		/// </summary>
		/// <param name="richText">Text value including RTF codes</param>
		public ZoomRichTextNode(string richText) : base(richText)
		{
		}

		#region IDraw interface

		/// <summary>
		/// Renders the rich text object to a graphics context.
		/// </summary>
		/// <param name="grfx">Graphics context object to render to</param>
		public override void Draw(System.Drawing.Graphics grfx)
		{
			if(this.Visible == true)
			{
				byte[] emfImage = RichText2EMF.BytesFromRichText(this.Width, this.Height, this.RichText);

				Matrix worldXform = Global.MatrixStack.Push(this.matrix, MatrixOrder.Prepend);

				Pen pen = new System.Drawing.Pen(Color.Black, 1);
				System.Drawing.Image img = Image.FromStream(new MemoryStream(emfImage));
				if (img != null)
				{
					grfx.DrawImage(img, this.Bounds);
				}
				else
				{
					grfx.DrawRectangle(pen, this.Bounds.Left, this.Bounds.Top, this.Bounds.Width, this.Bounds.Height);
				}
				pen.Dispose();

				Global.MatrixStack.Pop();
			}
		}

		#endregion

	}
}
